@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Generator, Union
+from typing import TYPE_CHECKING, Union
 
 if TYPE_CHECKING:
     from Akatosh import Actor
